@@ -20,16 +20,16 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "bytearraycolumnview_p.h"
+#include "bytearraycolumnview_p.hpp"
 
 // lib
-#include "oktetagui.h"
-#include "bordercolumnrenderer.h"
-#include "widgetcolumnstylist.h"
-#include "controller/dropper.h"
-#include "kcursor.h"
+#include "oktetagui.hpp"
+#include "bordercolumnrenderer.hpp"
+#include "widgetcolumnstylist.hpp"
+#include "controller/dropper.hpp"
+#include "cursor.hpp"
 // Okteta core
-#include <okteta/valuecodec.h>
+#include <Okteta/ValueCodec>
 // Qt
 #include <QStyle>
 #include <QFontDatabase>
@@ -304,7 +304,7 @@ void ByteArrayColumnViewPrivate::changeEvent(QEvent* event)
 
     q->setLineHeight(digitHeight);
 
-    // update all dependant structures
+    // update all dependent structures
     mTableLayout->setNoOfLinesPerPage(q->noOfLinesPerPage());
 
     updateViewByWidth();
@@ -366,13 +366,13 @@ int ByteArrayColumnViewPrivate::fittingBytesPerLine() const
         availableWidth -= scrollbarExtent;
     }
 
-    enum KMatchTrial
+    enum MatchTrial
     {
         FirstRun,
         RerunWithScrollbarOn,
         TestWithoutScrollbar
     };
-    KMatchTrial matchRun = FirstRun;
+    MatchTrial matchRun = FirstRun;
 
     // prepare needed values
     const PixelX digitWidth = mValueColumn->digitWidth();
@@ -495,8 +495,8 @@ void ByteArrayColumnViewPrivate::setVisibleCodings(int newColumns)
         return;
     }
 
-    mValueColumn->setVisible(AbstractByteArrayView::ValueCodingId& newColumns);
-    mCharColumn->setVisible(AbstractByteArrayView::CharCodingId& newColumns);
+    mValueColumn->setVisible(AbstractByteArrayView::ValueCodingId & newColumns);
+    mCharColumn->setVisible(AbstractByteArrayView::CharCodingId & newColumns);
     mMiddleBorderColumn->setVisible(newColumns == AbstractByteArrayView::ValueAndCharCodings);
 
     // active column not visible anymore?
@@ -608,9 +608,7 @@ QRect ByteArrayColumnViewPrivate::cursorRect() const
     Q_Q(const ByteArrayColumnView);
 
     QRect cursorRect = mActiveColumn->byteRect(mTableCursor->coord());
-    const QPoint viewportPoint(cursorRect.x() - q->xOffset(), cursorRect.y() - q->yOffset());
-    const QPoint globalPoint = q->viewport()->mapToParent(viewportPoint);   // TODO: seems still missing some offset
-    cursorRect.setTopLeft(globalPoint);
+    cursorRect.translate(-q->xOffset(), -q->yOffset());
 
     return cursorRect;
 }
@@ -755,7 +753,8 @@ void ByteArrayColumnViewPrivate::updateChanged()
     }
 
     // collect affected buffer columns
-    QList<AbstractByteArrayColumnRenderer*> dirtyColumns;
+    QVector<AbstractByteArrayColumnRenderer*> dirtyColumns;
+    dirtyColumns.reserve(2);
 
     AbstractByteArrayColumnRenderer* column = mValueColumn;
     while (true) {
@@ -771,7 +770,7 @@ void ByteArrayColumnViewPrivate::updateChanged()
     }
 
     // any columns to paint?
-    if (dirtyColumns.size() > 0) {
+    if (!dirtyColumns.isEmpty()) {
         // calculate affected lines/indizes
         const LinePositionRange fullPositions(0, mTableLayout->noOfBytesPerLine() - 1);
         CoordRange visibleRange(fullPositions, q->visibleLines());
@@ -782,12 +781,11 @@ void ByteArrayColumnViewPrivate::updateChanged()
         while (getNextChangedRange(&changedRange, visibleRange)) {
             PixelY cy = q->yOffsetOfLine(changedRange.start().line());
 
-            QListIterator<AbstractByteArrayColumnRenderer*> columnIt(dirtyColumns);
             // only one line?
             if (changedRange.start().line() == changedRange.end().line()) {
                 const LinePositionRange changedPositions(changedRange.start().pos(), changedRange.end().pos());
-                while (columnIt.hasNext()) {
-                    const PixelXRange xPixels = columnIt.next()->xsOfLinePositionsInclSpaces(changedPositions);
+                for (auto column : qAsConst(dirtyColumns)) {
+                    const PixelXRange xPixels = column->xsOfLinePositionsInclSpaces(changedPositions);
 
                     q->viewport()->update(xPixels.start() - xOffset, cy, xPixels.width(), lineHeight);
                 }
@@ -796,8 +794,8 @@ void ByteArrayColumnViewPrivate::updateChanged()
             else {
                 // first line
                 const LinePositionRange firstChangedPositions(changedRange.start().pos(), fullPositions.end());
-                while (columnIt.hasNext()) {
-                    const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces(firstChangedPositions);
+                for (auto column : qAsConst(dirtyColumns)) {
+                    const PixelXRange XPixels = column->xsOfLinePositionsInclSpaces(firstChangedPositions);
 
                     q->viewport()->update(XPixels.start() - xOffset, cy, XPixels.width(), lineHeight);
                 }
@@ -805,9 +803,8 @@ void ByteArrayColumnViewPrivate::updateChanged()
                 // at least one full line?
                 for (int l = changedRange.start().line() + 1; l < changedRange.end().line(); ++l) {
                     cy += lineHeight;
-                    columnIt.toFront();
-                    while (columnIt.hasNext()) {
-                        const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces(fullPositions);
+                    for (auto column : qAsConst(dirtyColumns)) {
+                        const PixelXRange XPixels = column->xsOfLinePositionsInclSpaces(fullPositions);
 
                         q->viewport()->update(XPixels.start() - xOffset, cy, XPixels.width(), lineHeight);
                     }
@@ -815,10 +812,9 @@ void ByteArrayColumnViewPrivate::updateChanged()
 
                 // last line
                 cy += lineHeight;
-                columnIt.toFront();
                 const LinePositionRange lastChangedPositions(fullPositions.start(), changedRange.end().pos());
-                while (columnIt.hasNext()) {
-                    const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces(lastChangedPositions);
+                for (auto column : qAsConst(dirtyColumns)) {
+                    const PixelXRange XPixels = column->xsOfLinePositionsInclSpaces(lastChangedPositions);
 
                     q->viewport()->update(XPixels.start() - xOffset, cy, XPixels.width(), lineHeight);
                 }
