@@ -20,16 +20,16 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "bytearrayrowview_p.h"
+#include "bytearrayrowview_p.hpp"
 
 // lib
-#include "oktetagui.h"
-#include "bordercolumnrenderer.h"
-#include "widgetcolumnstylist.h"
-#include "controller/dropper.h"
-#include "kcursor.h"
+#include "oktetagui.hpp"
+#include "bordercolumnrenderer.hpp"
+#include "widgetcolumnstylist.hpp"
+#include "controller/dropper.hpp"
+#include "cursor.hpp"
 // Okteta core
-#include <okteta/valuecodec.h>
+#include <Okteta/ValueCodec>
 // Qt
 #include <QStyle>
 #include <QFontDatabase>
@@ -280,7 +280,7 @@ void ByteArrayRowViewPrivate::changeEvent(QEvent* event)
 
     q->setLineHeight(rowHeight);
 
-    // update all dependant structures
+    // update all dependent structures
     mTableLayout->setNoOfLinesPerPage(q->noOfLinesPerPage());
 
     updateViewByWidth();
@@ -338,13 +338,13 @@ int ByteArrayRowViewPrivate::fittingBytesPerLine() const
         availableWidth -= scrollbarExtent;
     }
 
-    enum KMatchTrial
+    enum MatchTrial
     {
         FirstRun,
         RerunWithScrollbarOn,
         TestWithoutScrollbar
     };
-    KMatchTrial matchRun = FirstRun;
+    MatchTrial matchRun = FirstRun;
 
     // prepare needed values
     const PixelX byteWidth = mByteArrayColumn->byteWidth();
@@ -576,9 +576,7 @@ QRect ByteArrayRowViewPrivate::cursorRect() const
     Q_Q(const ByteArrayRowView);
 
     QRect cursorRect = mByteArrayColumn->byteRect(mTableCursor->coord(), mActiveCoding);
-    const QPoint viewportPoint(cursorRect.x() - q->xOffset(), cursorRect.y() - q->yOffset());
-    const QPoint globalPoint = q->viewport()->mapToParent(viewportPoint);   // TODO: seems still missing some offset
-    cursorRect.setTopLeft(globalPoint);
+    cursorRect.translate(-q->xOffset(), -q->yOffset());
 
     return cursorRect;
 }
@@ -621,7 +619,7 @@ void ByteArrayRowViewPrivate::createCursorPixmaps()
     mByteArrayColumn->renderCursor(&painter, index, mActiveCoding);
     painter.end();
 
-    // calculat the shape
+    // calculate the shape
     PixelX cursorX;
     PixelX cursorW;
     if (isCursorBehind()) {
@@ -723,7 +721,7 @@ void ByteArrayRowViewPrivate::updateChanged()
     }
 
     // collect affected buffer columns
-    QList<ByteArrayRowColumnRenderer*> dirtyColumns;
+    QVector<ByteArrayRowColumnRenderer*> dirtyColumns;
 
     if (mByteArrayColumn->overlaps(Xs)) {
         dirtyColumns.append(mByteArrayColumn);
@@ -731,7 +729,7 @@ void ByteArrayRowViewPrivate::updateChanged()
     }
 
     // any columns to paint?
-    if (dirtyColumns.size() > 0) {
+    if (!dirtyColumns.isEmpty()) {
         // calculate affected lines/indizes
         const LinePositionRange fullPositions(0, mTableLayout->noOfBytesPerLine() - 1);
         CoordRange visibleRange(fullPositions, q->visibleLines());
@@ -742,12 +740,11 @@ void ByteArrayRowViewPrivate::updateChanged()
         while (getNextChangedRange(&changedRange, visibleRange)) {
             PixelY cy = q->yOffsetOfLine(changedRange.start().line());
 
-            QListIterator<ByteArrayRowColumnRenderer*> columnIt(dirtyColumns);
             // only one line?
             if (changedRange.start().line() == changedRange.end().line()) {
                 const LinePositionRange changedPositions(changedRange.start().pos(), changedRange.end().pos());
-                while (columnIt.hasNext()) {
-                    const PixelXRange xPixels = columnIt.next()->xsOfLinePositionsInclSpaces(changedPositions);
+                for (auto column : qAsConst(dirtyColumns)) {
+                    const PixelXRange xPixels = column->xsOfLinePositionsInclSpaces(changedPositions);
 
                     q->viewport()->update(xPixels.start() - xOffset, cy, xPixels.width(), lineHeight);
                 }
@@ -756,8 +753,8 @@ void ByteArrayRowViewPrivate::updateChanged()
             else {
                 // first line
                 const LinePositionRange firstChangedPositions(changedRange.start().pos(), fullPositions.end());
-                while (columnIt.hasNext()) {
-                    const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces(firstChangedPositions);
+                for (auto column : qAsConst(dirtyColumns)) {
+                    const PixelXRange XPixels = column->xsOfLinePositionsInclSpaces(firstChangedPositions);
 
                     q->viewport()->update(XPixels.start() - xOffset, cy, XPixels.width(), lineHeight);
                 }
@@ -765,9 +762,8 @@ void ByteArrayRowViewPrivate::updateChanged()
                 // at least one full line?
                 for (int l = changedRange.start().line() + 1; l < changedRange.end().line(); ++l) {
                     cy += lineHeight;
-                    columnIt.toFront();
-                    while (columnIt.hasNext()) {
-                        const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces(fullPositions);
+                    for (auto column : qAsConst(dirtyColumns)) {
+                        const PixelXRange XPixels = column->xsOfLinePositionsInclSpaces(fullPositions);
 
                         q->viewport()->update(XPixels.start() - xOffset, cy, XPixels.width(), lineHeight);
                     }
@@ -775,10 +771,9 @@ void ByteArrayRowViewPrivate::updateChanged()
 
                 // last line
                 cy += lineHeight;
-                columnIt.toFront();
                 const LinePositionRange lastChangedPositions(fullPositions.start(), changedRange.end().pos());
-                while (columnIt.hasNext()) {
-                    const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces(lastChangedPositions);
+                for (auto column : qAsConst(dirtyColumns)) {
+                    const PixelXRange XPixels = column->xsOfLinePositionsInclSpaces(lastChangedPositions);
 
                     q->viewport()->update(XPixels.start() - xOffset, cy, XPixels.width(), lineHeight);
                 }
