@@ -22,14 +22,14 @@
 #include <QScriptEngine>
 #include <limits>
 
-#include <okteta/bytearraymodel.h>
+#include <Okteta/ByteArrayModel>
 
-#include "view/structures/datatypes/array/arraydatainformation.h"
-#include "view/structures/datatypes/array/primitivearraydata.h"
-#include "view/structures/datatypes/topleveldatainformation.h"
-#include "view/structures/datatypes/primitive/primitivetemplateinfo.h"
-#include "view/structures/datatypes/primitivefactory.h"
-#include "view/structures/script/scriptengineinitializer.h"
+#include "view/structures/datatypes/array/arraydatainformation.hpp"
+#include "view/structures/datatypes/array/primitivearraydata.hpp"
+#include "view/structures/datatypes/topleveldatainformation.hpp"
+#include "view/structures/datatypes/primitive/primitivetemplateinfo.hpp"
+#include "view/structures/datatypes/primitivefactory.hpp"
+#include "view/structures/script/scriptengineinitializer.hpp"
 
 class PrimitiveArrayTest : public QObject
 {
@@ -77,8 +77,8 @@ private:
 #error unknown byte order
 #endif
 
-static const uint SIZE = 8192;
-static const uint ENDIAN_SIZE = 16;
+static constexpr uint SIZE = 8192;
+static constexpr uint ENDIAN_SIZE = 16;
 
 void PrimitiveArrayTest::initTestCase()
 {
@@ -103,7 +103,7 @@ void PrimitiveArrayTest::initTestCase()
         data[i] = char(qrand() & 0xff);
     }
 
-    Okteta::Byte* copy = new Okteta::Byte[SIZE];
+    auto* copy = new Okteta::Byte[SIZE];
     memcpy(copy, data.data(), SIZE);
     model.reset(new Okteta::ByteArrayModel(copy, SIZE));
     model->setAutoDelete(true);
@@ -114,7 +114,7 @@ void PrimitiveArrayTest::initTestCase()
         endianData[i] = i;
     }
 
-    Okteta::Byte* endianCopy = new Okteta::Byte[SIZE];
+    auto* endianCopy = new Okteta::Byte[SIZE];
     memcpy(endianCopy, endianData.data(), ENDIAN_SIZE);
     endianModel.reset(new Okteta::ByteArrayModel(endianCopy, ENDIAN_SIZE));
     endianModel->setAutoDelete(true);
@@ -144,9 +144,9 @@ bool PrimitiveArrayTest::compareItems(float first, float second, uint index)
             firstUn.floating = first;
             secondUn.floating = second;
             return firstUn.integer == secondUn.integer;
-        } else {
-            return false;
         }
+
+        return false;
     }
     return first == second;
 }
@@ -167,9 +167,9 @@ bool PrimitiveArrayTest::compareItems(double first, double second, uint index)
             firstUn.floating = first;
             secondUn.floating = second;
             return firstUn.integer == secondUn.integer;
-        } else {
-            return false;
         }
+
+        return false;
     }
     return first == second;
 }
@@ -199,9 +199,9 @@ void PrimitiveArrayTest::testReadCustomizedPrimitiveInternal()
     primInfo->setCustomTypeName(QStringLiteral("mytype"));
     primInfo->setToStringFunction(engine->newFunction(customToStringFunc));
 
-    ArrayDataInformation* dataInf = new ArrayDataInformation(QStringLiteral("values"),
-                                                             endianModel->size() / sizeof(T),
-                                                             primInfo);
+    auto* dataInf = new ArrayDataInformation(QStringLiteral("values"),
+                                             endianModel->size() / sizeof(T),
+                                             primInfo);
     QScopedPointer<TopLevelDataInformation> top(new TopLevelDataInformation(dataInf, nullptr, engine));
 
     QCOMPARE(dataInf->childCount(), uint(ENDIAN_SIZE / sizeof(T)));
@@ -210,8 +210,7 @@ void PrimitiveArrayTest::testReadCustomizedPrimitiveInternal()
     QCOMPARE(Okteta::Size(result), endianModel->size() * 8);
     T* dataAsT = reinterpret_cast<T*>(endianData.data());
     QVERIFY(!dataInf->mData->isComplex());
-    PrimitiveArrayData<primType>* arrayData =
-        static_cast<PrimitiveArrayData<primType>*>(dataInf->mData.data());
+    auto* arrayData = static_cast<PrimitiveArrayData<primType>*>(dataInf->mData.data());
 
     // Verify byteOrder of values. The data is set up without palindromes.
     if (sizeof(T) > 1) {
@@ -240,7 +239,7 @@ template <PrimitiveDataType primType, typename T>
 void PrimitiveArrayTest::testReadPrimitiveInternal()
 {
     LoggerWithContext lwc(nullptr, QString());
-    ArrayDataInformation* dataInf = new ArrayDataInformation(QStringLiteral("values"),
+    auto* dataInf = new ArrayDataInformation(QStringLiteral("values"),
                                                              model->size() / sizeof(T),
                                                              PrimitiveFactory::newInstance(QStringLiteral("value"), primType, lwc));
     dataInf->setByteOrder(CURRENT_BYTE_ORDER);
@@ -252,8 +251,7 @@ void PrimitiveArrayTest::testReadPrimitiveInternal()
     QCOMPARE(Okteta::Size(result), model->size() * 8);
     T* dataAsT = reinterpret_cast<T*>(data.data());
     QVERIFY(!dataInf->mData->isComplex());
-    PrimitiveArrayData<primType>* arrayData =
-        static_cast<PrimitiveArrayData<primType>*>(dataInf->mData.data());
+    auto* arrayData = static_cast<PrimitiveArrayData<primType>*>(dataInf->mData.data());
     for (uint i = 0; i < dataInf->childCount(); ++i) {
         AllPrimitiveTypes childDataAll = arrayData->valueAt(i);
         T childData = childDataAll.value<T>();
