@@ -20,25 +20,26 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "bookmarkscontroller.h"
+#include "bookmarkscontroller.hpp"
 
 // controller
-#include "bookmarkeditpopup.h"
-// lib
-#include <kasten/okteta/bytearrayview.h>
-#include <kasten/okteta/bytearraydocument.h>
+#include "bookmarkeditpopup.hpp"
+// Okteta Kasten gui
+#include <Kasten/Okteta/ByteArrayView>
+// Okteta Kasten core
+#include <Kasten/Okteta/ByteArrayDocument>
 // Kasten core
-#include <kasten/abstractmodel.h>
+#include <Kasten/AbstractModel>
 // Okteta gui
-#include <okteta/offsetformat.h>
+#include <Okteta/OffsetFormat>
 // Okteta core
-#include <okteta/wordbytearrayservice.h>
-#include <okteta/charcodec.h>
-#include <okteta/bookmarkable.h>
-#include <okteta/bookmarksconstiterator.h>
-#include <okteta/bookmark.h>
-#include <okteta/abstractbytearraymodel.h>
-// KF5
+#include <Okteta/TextByteArrayAnalyzer>
+#include <Okteta/CharCodec>
+#include <Okteta/Bookmarkable>
+#include <Okteta/BookmarksConstIterator>
+#include <Okteta/Bookmark>
+#include <Okteta/AbstractByteArrayModel>
+// KF
 #include <KXMLGUIClient>
 #include <KLocalizedString>
 #include <KActionCollection>
@@ -48,7 +49,7 @@
 
 namespace Kasten {
 
-static const char BookmarkListActionListId[] = "bookmark_list";
+static constexpr char BookmarkListActionListId[] = "bookmark_list";
 
 // TODO: Sortieren nach Offset oder Zeit
 
@@ -121,11 +122,11 @@ void BookmarksController::setTargetModel(AbstractModel* model)
     int bookmarksCount = 0;
     if (hasViewWithBookmarks) {
         bookmarksCount = mBookmarks->bookmarksCount();
-        connect(mByteArray, SIGNAL(bookmarksAdded(QList<Okteta::Bookmark>)),
-                SLOT(onBookmarksAdded(QList<Okteta::Bookmark>)));
-        connect(mByteArray, SIGNAL(bookmarksRemoved(QList<Okteta::Bookmark>)),
-                SLOT(onBookmarksRemoved(QList<Okteta::Bookmark>)));
-        connect(mByteArray, SIGNAL(bookmarksModified(QList<int>)),
+        connect(mByteArray, SIGNAL(bookmarksAdded(QVector<Okteta::Bookmark>)),
+                SLOT(onBookmarksAdded(QVector<Okteta::Bookmark>)));
+        connect(mByteArray, SIGNAL(bookmarksRemoved(QVector<Okteta::Bookmark>)),
+                SLOT(onBookmarksRemoved(QVector<Okteta::Bookmark>)));
+        connect(mByteArray, SIGNAL(bookmarksModified(QVector<int>)),
                 SLOT(updateBookmarks()));
         connect(mByteArrayView, &ByteArrayView::cursorPositionChanged,
                 this, &BookmarksController::onCursorPositionChanged);
@@ -163,8 +164,8 @@ void BookmarksController::updateBookmarks()
 
     char codedOffset[Okteta::OffsetFormat::MaxFormatWidth + 1];
 
-    static const int firstWithNumericShortCut = 1;
-    static const int lastWithNumericShortCut = 9;
+    constexpr int firstWithNumericShortCut = 1;
+    constexpr int lastWithNumericShortCut = 9;
     int b = firstWithNumericShortCut;
 
     Okteta::BookmarksConstIterator bit = mBookmarks->createBookmarksConstIterator();
@@ -177,7 +178,7 @@ void BookmarksController::updateBookmarks()
             // = KStringHandler::rsqueeze( view->title(), MaxEntryLength );
             ++b;
         }
-        QAction* action = new QAction(title, mBookmarksActionGroup);
+        auto* action = new QAction(title, mBookmarksActionGroup);
 
         action->setData(bookmark.offset());
         mBookmarksActionGroup->addAction(action);
@@ -186,7 +187,7 @@ void BookmarksController::updateBookmarks()
                                mBookmarksActionGroup->actions());
 }
 
-void BookmarksController::onBookmarksAdded(const QList<Okteta::Bookmark>& bookmarks)
+void BookmarksController::onBookmarksAdded(const QVector<Okteta::Bookmark>& bookmarks)
 {
     Q_UNUSED(bookmarks)
     const int currentPosition = mByteArrayView->cursorPosition();
@@ -200,7 +201,7 @@ void BookmarksController::onBookmarksAdded(const QList<Okteta::Bookmark>& bookma
     updateBookmarks();
 }
 
-void BookmarksController::onBookmarksRemoved(const QList<Okteta::Bookmark>& bookmarks)
+void BookmarksController::onBookmarksRemoved(const QVector<Okteta::Bookmark>& bookmarks)
 {
     Q_UNUSED(bookmarks)
     const int currentPosition = mByteArrayView->cursorPosition();
@@ -245,15 +246,15 @@ void BookmarksController::createBookmark()
 
     // search for text at cursor
     const Okteta::CharCodec* charCodec = Okteta::CharCodec::createCodec(mByteArrayView->charCodingName());
-    const Okteta::WordByteArrayService textService(mByteArray, charCodec);
-    QString bookmarkName = textService.text(cursorPosition, cursorPosition + MaxBookmarkNameSize - 1);
+    const Okteta::TextByteArrayAnalyzer textAnalyzer(mByteArray, charCodec);
+    QString bookmarkName = textAnalyzer.text(cursorPosition, cursorPosition + MaxBookmarkNameSize - 1);
     delete charCodec;
 
     if (bookmarkName.isEmpty()) {
         bookmarkName = i18nc("default name of a bookmark", "Bookmark");  // %1").arg( 0 ) ); // TODO: use counter like with new file, globally
 
     }
-    BookmarkEditPopup* bookmarkEditPopup = new BookmarkEditPopup(mByteArrayView->widget());
+    auto* bookmarkEditPopup = new BookmarkEditPopup(mByteArrayView->widget());
     QPoint popupPoint = mByteArrayView->cursorRect().topLeft();
 //     popupPoint.ry() += mSlider->height() / 2;
     popupPoint = mByteArrayView->widget()->mapToGlobal(popupPoint);
@@ -266,7 +267,7 @@ void BookmarksController::createBookmark()
         Okteta::Bookmark bookmark(cursorPosition);
         bookmark.setName(bookmarkEditPopup->name());
 
-        const QList<Okteta::Bookmark> bookmarks { bookmark };
+        const QVector<Okteta::Bookmark> bookmarks { bookmark };
         mBookmarks->addBookmarks(bookmarks);
     }
     delete bookmarkEditPopup;
@@ -275,7 +276,7 @@ void BookmarksController::createBookmark()
 void BookmarksController::deleteBookmark()
 {
     const int cursorPosition = mByteArrayView->cursorPosition();
-    const QList<Okteta::Bookmark> bookmarks { cursorPosition };
+    const QVector<Okteta::Bookmark> bookmarks { cursorPosition };
     mBookmarks->removeBookmarks(bookmarks);
 }
 
