@@ -20,11 +20,11 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "shiftbytearrayfilter.h"
+#include "shiftbytearrayfilter.hpp"
 
 // Okteta core
-#include <okteta/abstractbytearraymodel.h>
-// KF5
+#include <Okteta/AbstractByteArrayModel>
+// KF
 #include <KLocalizedString>
 // Qt
 #include <QtGlobal>
@@ -32,7 +32,7 @@
 #include <cstdlib>
 
 // TODO: add option which bit (0/1) to insert
-static const int ShiftBitsPerByte = 8;
+static constexpr int ShiftBitsPerByte = 8;
 
 ShiftByteArrayFilter::ShiftByteArrayFilter()
     : AbstractByteArrayFilter(
