@@ -20,13 +20,13 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "replacecontroller.h"
+#include "replacecontroller.hpp"
 
 // controller
-#include "kreplacedialog.h"
-#include "kreplaceprompt.h"
-#include "replacetool.h"
-// KF5
+#include "replacedialog.hpp"
+#include "replaceprompt.hpp"
+#include "replacetool.hpp"
+// KF
 #include <KXmlGuiWindow>
 #include <KLocalizedString>
 #include <KActionCollection>
@@ -72,7 +72,7 @@ void ReplaceController::replace()
 {
     // ensure dialog
     if (!mReplaceDialog) {
-        mReplaceDialog = new KReplaceDialog(mTool, mParentWidget);
+        mReplaceDialog = new ReplaceDialog(mTool, mParentWidget);
     }
 
     mReplaceDialog->show();
@@ -96,7 +96,7 @@ void ReplaceController::onFinished(bool previousFound, int noOfReplacements)
     }
 }
 
-bool ReplaceController::queryContinue(KFindDirection direction, int noOfReplacements) const
+bool ReplaceController::queryContinue(FindDirection direction, int noOfReplacements) const
 {
     const QString messageBoxTitle = i18nc("@title:window", "Replace");
     const QString replacementReport = (noOfReplacements == 0) ?
@@ -118,7 +118,7 @@ bool ReplaceController::queryContinue(KFindDirection direction, int noOfReplacem
 ReplaceBehaviour ReplaceController::queryReplaceCurrent() const
 {
     if (!mReplacePrompt) {
-        mReplacePrompt = new KReplacePrompt(mParentWidget);
+        mReplacePrompt = new ReplacePrompt(mParentWidget);
     }
 
     mReplacePrompt->show();
