@@ -19,9 +19,9 @@
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
-#include "chardatainformation.h"
+#include "chardatainformation.hpp"
 
-// KF5
+// KF
 #include <KLocalizedString>
 // Qt
 #include <QLocale>
@@ -77,7 +77,7 @@ QWidget* CharDataInformationMethods::staticCreateEditWidget(QWidget* parent)
 QVariant CharDataInformationMethods::staticDataFromWidget(const QWidget* w)
 {
     // TODO fix this code!!
-    const QLineEdit* edit = qobject_cast<const QLineEdit*> (w);
+    const auto* edit = qobject_cast<const QLineEdit*> (w);
     if (edit) {
         QString text = edit->text();
         if (text.length() == 0) {
@@ -98,22 +98,24 @@ QVariant CharDataInformationMethods::staticDataFromWidget(const QWidget* w)
                     return val;
                 }
                 return {};
-            } else if (text.at(1) == QLatin1Char('n')) {
-                return (quint8) '\n'; // newline
-            } else if (text.at(1) == QLatin1Char('t')) {
-                return (quint8) '\t'; // tab
-            } else if (text.at(1) == QLatin1Char('r')) {
-                return (quint8) '\r'; // cr
-            } else {
-                // octal escape:
-                bool okay;
-                const QStringRef valStr = text.midRef(1, 3); // only 2 chars
-                quint8 val = valStr.toInt(&okay, 8);
-                if (okay) {
-                    return val;
-                }
-                return {};
             }
+            if (text.at(1) == QLatin1Char('n')) {
+                return (quint8) '\n'; // newline
+            }
+            if (text.at(1) == QLatin1Char('t')) {
+                return (quint8) '\t'; // tab
+            }
+            if (text.at(1) == QLatin1Char('r')) {
+                return (quint8) '\r'; // cr
+            }
+            // octal escape:
+            bool okay;
+            const QStringRef valStr = text.midRef(1, 3); // only 2 chars
+            quint8 val = valStr.toInt(&okay, 8);
+            if (okay) {
+                return val;
+            }
+            return {};
         }
     }
     return {};
@@ -121,7 +123,7 @@ QVariant CharDataInformationMethods::staticDataFromWidget(const QWidget* w)
 
 void CharDataInformationMethods::staticSetWidgetData(quint8 value, QWidget* w)
 {
-    QLineEdit* edit = qobject_cast<QLineEdit*> (w);
+    auto* edit = qobject_cast<QLineEdit*> (w);
     if (edit) {
         QChar qchar(value, 0);
         if (!qchar.isPrint()) {
