@@ -21,18 +21,18 @@
  *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "stringdatainformation.h"
-#include "../dummydatainformation.h"
-#include "../topleveldatainformation.h"
-#include "utf32stringdata.h"
-#include "utf16stringdata.h"
-#include "utf8stringdata.h"
-#include "asciistringdata.h"
-#include "ebcdicstringdata.h"
-#include "latin1stringdata.h"
-#include "../../script/classes/stringscriptclass.h"
-#include "../../script/scripthandlerinfo.h"
-#include "../../script/scriptlogger.h"
+#include "stringdatainformation.hpp"
+#include "../dummydatainformation.hpp"
+#include "../topleveldatainformation.hpp"
+#include "utf32stringdata.hpp"
+#include "utf16stringdata.hpp"
+#include "utf8stringdata.hpp"
+#include "asciistringdata.hpp"
+#include "ebcdicstringdata.hpp"
+#include "latin1stringdata.hpp"
+#include "../../script/classes/stringscriptclass.hpp"
+#include "../../script/scripthandlerinfo.hpp"
+#include "../../script/scriptlogger.hpp"
 
 #include <QScriptEngine>
 #include <QBrush>
@@ -51,8 +51,6 @@ StringDataInformation::StringDataInformation(const QString& name, StringType enc
 StringDataInformation::StringDataInformation(const StringDataInformation& d)
     : DataInformationWithDummyChildren(d)
     , mDummy(new DummyDataInformation(this))
-    , mData(nullptr)
-    , mEncoding(StringType::InvalidEncoding)
 {
     setEncoding(d.mEncoding); // sets mData
     mData->copyTerminationFrom(d.mData.data());
@@ -150,9 +148,11 @@ QVariant StringDataInformation::childData(int row, int column, int role) const
         if (column == ColumnName) {
             // TODO termination char
             return QString(QLatin1Char('[') + QString::number(row) + QLatin1Char(']'));
-        } else if (column == ColumnType) {
+        }
+        if (column == ColumnType) {
             return mData->charType();
-        } else if (column == ColumnValue) {
+        }
+        if (column == ColumnValue) {
             return mData->stringValue(row);
         }
     }
@@ -296,7 +296,8 @@ QVariant StringDataInformation::data(int column, int role) const
     if (mData->wasEof()) {
         if (role == Qt::BackgroundRole) {
             return QBrush(Qt::yellow);
-        } else if (role == Qt::ToolTipRole) {
+        }
+        if (role == Qt::ToolTipRole) {
             return i18n("End of file reached prematurely");
         }
     }
