@@ -19,8 +19,8 @@
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
-#include "uniondatainformation.h"
-#include "topleveldatainformation.h"
+#include "uniondatainformation.hpp"
+#include "topleveldatainformation.hpp"
 
 #include <KLocalizedString>
 
@@ -97,7 +97,7 @@ BitCount64 UnionDataInformation::childPosition(const DataInformation* child, Okt
     Q_UNUSED(child)
     if (mParent->isTopLevel()) {
         return start * 8;
-    } else {
-        return mParent->asDataInformation()->childPosition(this, start);
     }
+
+    return mParent->asDataInformation()->childPosition(this, start);
 }
