@@ -20,14 +20,14 @@
  *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "scriptfileparser.h"
+#include "scriptfileparser.hpp"
 
-#include "scriptvalueconverter.h"
-#include "parserutils.h"
-#include "../datatypes/topleveldatainformation.h"
-#include "../datatypes/dummydatainformation.h"
-#include "../script/scriptengineinitializer.h"
-#include "../script/scriptlogger.h"
+#include "scriptvalueconverter.hpp"
+#include "parserutils.hpp"
+#include "../datatypes/topleveldatainformation.hpp"
+#include "../datatypes/dummydatainformation.hpp"
+#include "../script/scriptengineinitializer.hpp"
+#include "../script/scriptlogger.hpp"
 
 #include <QScriptEngine>
 
@@ -48,7 +48,7 @@ QVector<TopLevelDataInformation*> ScriptFileParser::parseStructures() const
     QVector<TopLevelDataInformation*> ret;
 
     QScriptEngine* engine = ScriptEngineInitializer::newEngine();
-    ScriptLogger* logger = new ScriptLogger();
+    auto* logger = new ScriptLogger();
 
     QScriptValue value = loadScriptValue(logger, engine);
     DataInformation* dataInf;
@@ -62,7 +62,7 @@ QVector<TopLevelDataInformation*> ScriptFileParser::parseStructures() const
         dataInf = new DummyDataInformation(nullptr, mPluginName);
     }
     const QFileInfo fileInfo(mAbsolutePath);
-    TopLevelDataInformation* top = new TopLevelDataInformation(dataInf, logger, engine, fileInfo);
+    auto* top = new TopLevelDataInformation(dataInf, logger, engine, fileInfo);
     // handle default lock offset
     QScriptValue lockOffset = value.property(ParserStrings::PROPERTY_DEFAULT_LOCK_OFFSET());
     if (lockOffset.isValid()) {
