@@ -21,14 +21,14 @@
  License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "structuresmanagerview.h"
-#include "structureaddremovewidget.h"
+#include "structuresmanagerview.hpp"
+#include "structureaddremovewidget.hpp"
 
 #include "structureviewpreferences.h"
-#include "../structuresmanager.h"
-#include "../structurestool.h"
-#include "../structlogging.h"
-// KF5
+#include "../structuresmanager.hpp"
+#include "../structurestool.hpp"
+#include "../structlogging.hpp"
+// KF
 #include <KPluginSelector>
 #include <KConfigDialogManager>
 #include <KPluginInfo>
@@ -49,13 +49,13 @@ StructuresManagerView::StructuresManagerView(Kasten::StructuresTool* tool, QWidg
 {
     mSelectedStructures = Kasten::StructureViewPreferences::loadedStructures();
 
-    QVBoxLayout* pageLayout = new QVBoxLayout();
-    pageLayout->setMargin(0);
+    auto* pageLayout = new QVBoxLayout();
+    pageLayout->setContentsMargins(0, 0, 0, 0);
     setLayout(pageLayout);
 
     rebuildPluginSelectorEntries();
 
-    QHBoxLayout* buttonsLayout = new QHBoxLayout();
+    auto* buttonsLayout = new QHBoxLayout();
     pageLayout->addLayout(buttonsLayout);
 
     mGetNewStructuresButton = new KNS3::Button(i18n("Get New Structures..."),
@@ -99,10 +99,11 @@ QStringList StructuresManagerView::values() const
 
 void StructuresManagerView::advancedSelection()
 {
-    StructureAddRemoveWidget* advancedSelectionWidget = new StructureAddRemoveWidget(mSelectedStructures, mTool, this);
+    auto* advancedSelectionWidget = new StructureAddRemoveWidget(mSelectedStructures, mTool, this);
     QPointer<QDialog> dlg = new QDialog(this); // the dlg-on-heap-variant
-    QVBoxLayout* layout = new QVBoxLayout;
-    QDialogButtonBox* dialogButtonBox = new QDialogButtonBox;
+    dlg->setWindowTitle(i18nc("@title:window", "Advanced Structures Selection"));
+    auto* layout = new QVBoxLayout;
+    auto* dialogButtonBox = new QDialogButtonBox;
     dialogButtonBox->addButton(QDialogButtonBox::Ok);
     connect(dialogButtonBox, &QDialogButtonBox::accepted, dlg.data(), &QDialog::accept);
     dialogButtonBox->addButton(QDialogButtonBox::Cancel);
@@ -174,7 +175,7 @@ void StructuresManagerView::rebuildPluginSelectorEntries()
     }
 
     // XXX is there any way to clear the plugins selector?
-    QBoxLayout* layoutObj = qobject_cast<QBoxLayout*>(layout());
+    auto* layoutObj = qobject_cast<QBoxLayout*>(layout());
     Q_CHECK_PTR(layoutObj);
     if (mStructuresSelector) {
         layoutObj->removeWidget(mStructuresSelector);
