@@ -20,11 +20,11 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "viewprofiletablemodel.h"
+#include "viewprofiletablemodel.hpp"
 
 // Okteta Gui Kasten
-#include <kasten/okteta/bytearrayviewprofilemanager.h>
-// KF5
+#include <Kasten/Okteta/ByteArrayViewProfileManager>
+// KF
 #include <KColorScheme>
 #include <KLocalizedString>
 // Qt
@@ -132,7 +132,7 @@ ViewProfileTableModel::row(const ByteArrayViewProfile::Id& viewProfileId) const
 {
     int result = -1;
 
-    const QList<ByteArrayViewProfile> viewProfiles = mViewProfileManager->viewProfiles();
+    const QVector<ByteArrayViewProfile> viewProfiles = mViewProfileManager->viewProfiles();
     const int viewProfilesCount = viewProfiles.count();
     for (int i = 0; i < viewProfilesCount; ++i) {
         if (viewProfileId == viewProfiles.at(i).id()) {
@@ -157,9 +157,9 @@ void ViewProfileTableModel::onViewProfilesChanged()
     endResetModel();
 }
 
-void ViewProfileTableModel::onViewProfileLocksChanged(const QList<ByteArrayViewProfile::Id>& viewProfileIds)
+void ViewProfileTableModel::onViewProfileLocksChanged(const QVector<ByteArrayViewProfile::Id>& viewProfileIds)
 {
-    const QList<ByteArrayViewProfile> viewProfiles = mViewProfileManager->viewProfiles();
+    const QVector<ByteArrayViewProfile> viewProfiles = mViewProfileManager->viewProfiles();
     const int viewProfilesCount = viewProfiles.count();
     for (int i = 0; i < viewProfilesCount; ++i) {
         const ByteArrayViewProfile::Id viewProfileId = viewProfiles.at(i).id();
