@@ -20,13 +20,11 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "bytearraydocument.h"
+#include "bytearraydocument.hpp"
 
-//
-#include <kasten/person.h>
 // Okteta core
-#include <okteta/piecetablebytearraymodel.h>
-// KF5
+#include <Okteta/PieceTableByteArrayModel>
+// KF
 #include <KLocalizedString>
 
 using Okteta::PieceTableByteArrayModel;
@@ -104,35 +102,4 @@ void ByteArrayDocument::onHeadVersionDescriptionChanged(const QString& newDescri
     emit headVersionDataChanged(data);
 }
 
-Person ByteArrayDocument::owner() const
-{
-    return mUserList.size() > 0 ? mUserList.at(0) : Person();
-}
-
-QList<Person> ByteArrayDocument::userList() const
-{
-    return mUserList;
-}
-
-void ByteArrayDocument::setOwner(const Person& owner)
-{
-    mUserList.append(owner);
-}
-
-void ByteArrayDocument::addUsers(const QList<Person>& users)
-{
-    mUserList.append(users);
-
-    emit usersAdded(users);
-}
-
-void ByteArrayDocument::removeUsers(const QList<Person>& users)
-{
-    for (const Person& user : users) {
-        mUserList.removeOne(user);
-    }
-
-    emit usersRemoved(users);
-}
-
 }
