@@ -20,15 +20,15 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "bytearrayrawfileloadthread.h"
+#include "bytearrayrawfileloadthread.hpp"
 
 // lib
-#include "bytearraydocument.h"
+#include "bytearraydocument.hpp"
 // Kasten core
-#include <kasten/person.h>
+// #include <Kasten/Person>
 // Okteta core
-#include <okteta/piecetablebytearraymodel.h>
-// KF5
+#include <Okteta/PieceTableByteArrayModel>
+// KF
 #include <KLocalizedString>
 // Qt
 #include <QCoreApplication>
@@ -63,11 +63,11 @@ void ByteArrayRawFileLoadThread::run()
             success = (inStream.status() == QDataStream::Ok);
 
             if (success) {
-                Okteta::PieceTableByteArrayModel* byteArray = new Okteta::PieceTableByteArrayModel(data);
+                auto* byteArray = new Okteta::PieceTableByteArrayModel(data);
                 byteArray->setModified(false);
 
                 mDocument = new ByteArrayDocument(byteArray, i18nc("destination of the byte array", "Loaded from file."));
-                mDocument->setOwner(Person::createEgo());
+//                 mDocument->setOwner(Person::createEgo());
                 // TODO: make PieceTableByteArrayModel a child by constructor argument parent
                 byteArray->moveToThread(QCoreApplication::instance()->thread());
                 mDocument->moveToThread(QCoreApplication::instance()->thread());
