@@ -20,16 +20,17 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "bytearrayview.h"
+#include "bytearrayview.hpp"
 
 // lib
-#include "bytearrayjanusview.h"
-#include <bytearrayviewprofilesynchronizer.h>
-#include <kasten/okteta/bytearraydocument.h>
+#include "bytearrayjanusview.hpp"
+#include <bytearrayviewprofilesynchronizer.hpp>
+// Okteta Kasten core
+#include <Kasten/Okteta/ByteArrayDocument>
 // Okteta gui
-#include <okteta/abstractbytearrayview.h>
+#include <Okteta/AbstractByteArrayView>
 // Okteta core
-#include <okteta/abstractbytearraymodel.h>
+#include <Okteta/AbstractByteArrayModel>
 // Qt
 #include <QFontDatabase>
 
@@ -143,6 +144,8 @@ void ByteArrayView::init()
     connect(mWidget, &ByteArrayJanusView::noOfGroupedBytesChanged, this, &ByteArrayView::noOfGroupedBytesChanged);
     connect(mWidget, &ByteArrayJanusView::zoomLevelChanged, this, &ByteArrayView::zoomLevelChanged);
     connect(mWidget, &ByteArrayJanusView::viewModusChanged, this, &ByteArrayView::viewModusChanged);
+
+    connect(mWidget, &ByteArrayJanusView::viewContextMenuRequested, this, &ByteArrayView::viewContextMenuRequested);
 }
 
 ByteArrayViewProfileSynchronizer* ByteArrayView::synchronizer() const { return mByteArrayViewProfileSynchronizer; }
