@@ -20,13 +20,13 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "closecontroller.h"
+#include "closecontroller.hpp"
 
 // Kasten gui
-#include <kasten/abstractdocumentstrategy.h>
+#include <Kasten/AbstractDocumentStrategy>
 // Kasten core
-#include <kasten/abstractdocument.h>
-// KF5
+#include <Kasten/AbstractDocument>
+// KF
 #include <KActionCollection>
 #include <KStandardAction>
 #include <KXMLGUIClient>
@@ -39,8 +39,7 @@ namespace Kasten {
 CloseController::CloseController(AbstractDocumentStrategy* documentStrategy,
                                  KXMLGUIClient* guiClient,
                                  bool supportMultiple)
-    : AbstractXmlGuiController()
-    , mDocumentStrategy(documentStrategy)
+    : mDocumentStrategy(documentStrategy)
 {
     KActionCollection* actionCollection = guiClient->actionCollection();
 
@@ -108,7 +107,7 @@ void CloseController::closeAllOther()
 
 void CloseController::onDocumentsChanged()
 {
-    const QList<AbstractDocument*> documents = mDocumentStrategy->documents();
+    const QVector<AbstractDocument*> documents = mDocumentStrategy->documents();
 
     const bool hasDocuments = !documents.isEmpty();
     // TODO: there could be just one, but not set for this tool?
