@@ -20,20 +20,20 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "copyascontroller.h"
+#include "copyascontroller.hpp"
 
 // lib
-#include "copyasdialog.h"
+#include "copyasdialog.hpp"
 // Kasten gui
-#include <kasten/modelcodecviewmanager.h>
-#include <kasten/dataselectable.h>
-#include <kasten/abstractmodelstreamencoderconfigeditor.h>
+#include <Kasten/ModelCodecViewManager>
+#include <Kasten/DataSelectable>
+#include <Kasten/AbstractModelStreamEncoderConfigEditor>
 // Kasten core
-#include <kasten/modelstreamencodethread.h>
-#include <kasten/modelcodecmanager.h>
-#include <kasten/abstractmodelstreamencoder.h>
-#include <kasten/abstractmodel.h>
-// KF5
+#include <Kasten/ModelStreamEncodeThread>
+#include <Kasten/ModelCodecManager>
+#include <Kasten/AbstractModelStreamEncoder>
+#include <Kasten/AbstractModel>
+// KF
 #include <KXMLGUIClient>
 #include <KXMLGUIFactory>
 #include <KActionCollection>
@@ -52,8 +52,7 @@ namespace Kasten {
 CopyAsController::CopyAsController(ModelCodecViewManager* modelCodecViewManager,
                                    ModelCodecManager* modelCodecManager,
                                    KXMLGUIClient* guiClient)
-    : AbstractXmlGuiController()
-    , mModelCodecViewManager(modelCodecViewManager)
+    : mModelCodecViewManager(modelCodecViewManager)
     , mModelCodecManager(modelCodecManager)
 {
     mCopyAsSelectAction = new KSelectAction(QIcon::fromTheme(QStringLiteral("edit-copy")),
@@ -91,14 +90,14 @@ void CopyAsController::updateActions()
 
     const AbstractModelSelection* selection = mSelectionControl ? mSelectionControl->modelSelection() : nullptr;
 
-    const QList<AbstractModelStreamEncoder*> encoderList =
+    const QVector<AbstractModelStreamEncoder*> encoderList =
         mModelCodecManager->encoderList(mModel, selection);
-    const bool hasEncoders = (encoderList.size() > 0);
+    const bool hasEncoders = (!encoderList.isEmpty());
 
     if (hasEncoders) {
         for (auto* encoder : encoderList) {
             const QString title = encoder->remoteTypeName();
-            QAction* action = new QAction(title, mCopyAsSelectAction);
+            auto* action = new QAction(title, mCopyAsSelectAction);
 
             action->setData(QVariant::fromValue(encoder));
             mCopyAsSelectAction->addAction(action);
@@ -115,7 +114,7 @@ void CopyAsController::updateActions()
 
 void CopyAsController::onActionTriggered(QAction* action)
 {
-    AbstractModelStreamEncoder* encoder = action->data().value<AbstractModelStreamEncoder*>();
+    auto* encoder = action->data().value<AbstractModelStreamEncoder*>();
 
     const AbstractModelSelection* selection = mSelectionControl->modelSelection();
 
@@ -125,7 +124,7 @@ void CopyAsController::onActionTriggered(QAction* action)
     if (configEditor) {
         CopyAsDialog* dialog = new CopyAsDialog(encoder->remoteTypeName(), configEditor);
         dialog->setData(mModel, selection);
-        if (!dialog->exec()) {
+        if (dialog->exec() == 0) {
             return;
         }
     }
@@ -136,8 +135,7 @@ void CopyAsController::onActionTriggered(QAction* action)
     QBuffer exportDataBuffer(&exportData);
     exportDataBuffer.open(QIODevice::WriteOnly);
 
-    ModelStreamEncodeThread* encodeThread =
-        new ModelStreamEncodeThread(this, &exportDataBuffer, mModel, selection, encoder);
+    auto* encodeThread = new ModelStreamEncodeThread(this, &exportDataBuffer, mModel, selection, encoder);
     encodeThread->start();
     while (!encodeThread->wait(100)) {
         QCoreApplication::processEvents(QEventLoop::ExcludeUserInputEvents | QEventLoop::ExcludeSocketNotifiers);
@@ -147,7 +145,7 @@ void CopyAsController::onActionTriggered(QAction* action)
 
     exportDataBuffer.close();
 
-    QMimeData* mimeData = new QMimeData;
+    auto* mimeData = new QMimeData;
     mimeData->setData(encoder->remoteClipboardMimeType(), exportData);
     QApplication::clipboard()->setMimeData(mimeData, QClipboard::Clipboard);
 
