@@ -20,10 +20,10 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "modeldatageneratethread.h"
+#include "modeldatageneratethread.hpp"
 
 // lib
-#include "abstractmodeldatagenerator.h"
+#include "abstractmodeldatagenerator.hpp"
 
 namespace Kasten {
 
