@@ -20,19 +20,20 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "abstractmodeldatageneratorconfigeditor.h"
+#include "abstractmodeldatageneratorconfigeditor.hpp"
 
 namespace Kasten {
 
+class AbstractModelDataGeneratorConfigEditorPrivate
+{
+};
+
+
 AbstractModelDataGeneratorConfigEditor::AbstractModelDataGeneratorConfigEditor(QWidget* parent)
     : QWidget(parent)
-    , d(nullptr)
 {}
 
-AbstractModelDataGeneratorConfigEditor::~AbstractModelDataGeneratorConfigEditor()
-{
-//     delete d;
-}
+AbstractModelDataGeneratorConfigEditor::~AbstractModelDataGeneratorConfigEditor() = default;
 
 bool AbstractModelDataGeneratorConfigEditor::isValid() const
 {
