@@ -20,10 +20,10 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "statusbarlayout.h"
+#include "statusbarlayout.hpp"
 
 // lib
-#include <kastengui.h>
+#include <kastengui.hpp>
 // Qt
 #include <QWidgetItem>
 #include <QWidget>
@@ -36,7 +36,7 @@ StatusBarLayout::StatusBarLayout(QWidget* parent)
     , mIsDirty(true)
     , mIsEmpty(true)
 {
-    setMargin(0);
+    setContentsMargins(0, 0, 0, 0);
 }
 
 StatusBarLayout::~StatusBarLayout()
@@ -215,7 +215,7 @@ void StatusBarLayout::setGeometry(const QRect& _rect)
 
 void StatusBarLayout::updateLayoutStructs() const
 {
-    StatusBarLayout* that = const_cast<StatusBarLayout*>(this);
+    auto* that = const_cast<StatusBarLayout*>(this);
 
 //     const int margin = this->margin();
     const int spacing = this->spacing();
