@@ -20,18 +20,18 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "multidocumentstrategy_p.h"
+#include "multidocumentstrategy_p.hpp"
 
 // lib
-#include "createdialog.h"
+#include "createdialog.hpp"
 // Kasten gui
-#include <abstractmodeldatageneratorconfigeditor.h>
-#include <modelcodecviewmanager.h>
-#include <viewmanager.h>
+#include <abstractmodeldatageneratorconfigeditor.hpp>
+#include <modelcodecviewmanager.hpp>
+#include <viewmanager.hpp>
 // Kasten core
-#include <kasten/modeldatageneratethread.h>
-#include <kasten/abstractmodeldatagenerator.h>
-#include <kasten/abstractmodel.h>
+#include <Kasten/ModelDataGenerateThread>
+#include <Kasten/AbstractModelDataGenerator>
+#include <Kasten/AbstractModel>
 // Qt
 #include <QClipboard>
 #include <QApplication>
@@ -72,17 +72,16 @@ void MultiDocumentStrategyPrivate::createNewWithGenerator(AbstractModelDataGener
         mViewManager->codecViewManager()->createConfigEditor(generator);
 
     if (configEditor) {
-        CreateDialog* dialog = new CreateDialog(configEditor);
+        auto* dialog = new CreateDialog(configEditor);
 //         dialog->setData( mModel, selection ); TODO
-        if (!dialog->exec()) {
+        if (dialog->exec() == 0) {
             return;
         }
     }
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
-    ModelDataGenerateThread* generateThread =
-        new ModelDataGenerateThread(q, generator);
+    auto* generateThread = new ModelDataGenerateThread(q, generator);
     generateThread->start();
     while (!generateThread->wait(100)) {
         QCoreApplication::processEvents(QEventLoop::ExcludeUserInputEvents | QEventLoop::ExcludeSocketNotifiers);
